searchData={"items":[{"type":"module","title":"AshMoney","doc":"`AshMoney` provides a type for working with money in your Ash resources.\n\nIt also provides an `AshPostgres.Extension` that can be used to add support for\nmoney types and operators to your Postgres database.","ref":"AshMoney.html"},{"type":"module","title":"AshMoney.Types.Money","doc":"A money type for Ash that uses the `ex_money` library.","ref":"AshMoney.Types.Money.html"},{"type":"extras","title":"Get Started With Ash Money","doc":"# Getting Started With AshMoney","ref":"get-started-with-ash-money.html"},{"type":"extras","title":"Bring in the ash_graphql dependency - Get Started With Ash Money","doc":"```elixir\ndef deps()\n  [\n    ...\n    {:ash_money, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"get-started-with-ash-money.html#bring-in-the-ash_graphql-dependency"},{"type":"extras","title":"Setup - Get Started With Ash Money","doc":"The primary thing that AshMoney provides is `AshMoney.Types.Money`. This is backed by `ex_money`. You can use it out of the box like so:\n\n```elixir\nattribute :balance, AshMoney.Types.Money\n```\n\nOr you can add it to your compile time list of types for easier reference:\n\n```elixir\nconfig :ash, :custom_types, money: AshMoney.Types.Money\n```\n\nThen compile ash again, `mix deps.compile ash --force`, and refer to it like so:\n\n```elixir\nattribute :balance, :money\n```","ref":"get-started-with-ash-money.html#setup"},{"type":"extras","title":"AshPostgres Support - Get Started With Ash Money","doc":"Thanks to `ex_money_sql`, there are excellent tools for lowering support for money into your postgres database. This allows for things like aggregates that sum amounts, and referencing money in expressions:\n\n```elixir\nsum :sum_of_usd_balances, :accounts, :balance do\n  filter expr(fragment(\"(?).currency_code\", balance).currency_code == \"USD\")\nend\n```\n\nTo install it, add `AshMoney.AshPostgresExtension` to your list of `installed_extensions` in your repo, and generate migrations.\n\n```elixir\ndefmodule YourRepo do\n  def installed_extensions do\n    [..., AshMoney.AshPostgresExtension]\n  end\nend\n```","ref":"get-started-with-ash-money.html#ashpostgres-support"},{"type":"extras","title":"AshGraphql Support - Get Started With Ash Money","doc":"Add the following to your schema file:\n\n```elixir\n  object :money do\n    field(:amount, non_null(:decimal))\n    field(:currency, non_null(:string))\n  end\n```","ref":"get-started-with-ash-money.html#ashgraphql-support"}],"content_type":"text/markdown"}